@@ -7,7 +7,7 @@ ncov <- nvar*(nvar+1)/2
 ainv <- single(ncov)
 cov <- single(ncov)
 f.res <- .Fortran("cfrcov",
-a=to.double(a),
+a=as.double(a),
 nvar=to.integer(nvar),
 ncov=to.integer(ncov),
 fc=to.single(fc),
