@@ -5,7 +5,7 @@ nn <- length(a)
 if (missing(a)) a <- double(nn)
 info <- integer(1)
 f.res <- .Fortran("mchld",
-a=to.double(a),
+a=as.double(a),
 n=to.integer(n),
 nn=to.integer(nn),
 info=to.integer(info))
