@@ -2,7 +2,7 @@
 function() {
 prec <- double(1)
 f.res <- .Fortran("precd",
-prec=to.double(prec))
+prec=as.double(prec))
 list(prec=f.res$prec)
 }
 
